@@ -1,23 +1,9 @@
 /*
-    Copyright 2008,2010,2011 Will Stephenson <wstephenson@kde.org>
-    Copyright 2011-2013 Lamarque Souza <lamarque@kde.org>
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2008, 2010, 2011 Will Stephenson <wstephenson@kde.org>
+    SPDX-FileCopyrightText: 2011-2013 Lamarque Souza <lamarque@kde.org>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef NETWORKMANAGERQT_NETWORKMANAGER_H
@@ -25,11 +11,8 @@
 
 #include <networkmanagerqt/networkmanagerqt_export.h>
 
-#include <QtGlobal>
-#include <QtDBus>
-
-#include "device.h"
 #include "activeconnection.h"
+#include "device.h"
 #include "dnsconfiguration.h"
 
 /**
@@ -44,17 +27,17 @@
  */
 namespace NetworkManager
 {
-    Q_NAMESPACE
+Q_NAMESPACE
 
 enum Status {
     Unknown, /**< the networking system is not active or unable to report its status - proceed with caution */
     Asleep, /**< networking is inactive and all devices are disabled */
-    Disconnected,/**< the system is not connected to any network */
+    Disconnected, /**< the system is not connected to any network */
     Disconnecting, /**< the system is breaking the connection */
     Connecting, /**< the system is not connected to any network */
     ConnectedLinkLocal, /**< a network device is connected, but there is only link-local connectivity */
     ConnectedSiteOnly, /**< a network device is connected, but there is only site-local connectivity */
-    Connected /**< the system is currently connected to a network */
+    Connected, /**< the system is currently connected to a network */
 };
 
 enum LogLevel {
@@ -62,13 +45,50 @@ enum LogLevel {
     Warning,
     Info,
     Debug,
-    Trace/**< = Debug in runtime NM < 0.9.10*/
-    };
+    Trace, /**< = Debug in runtime NM < 0.9.10*/
+};
 
-enum LogDomain {NoChange, None, Hardware, RFKill, Ethernet, WiFi, Bluetooth, MobileBroadBand, DHCP4, DHCP6, PPP, WiFiScan, IPv4, IPv6,
-                AutoIPv4, DNS, VPN, Sharing, Supplicant, UserSet, SysSet, Suspend, Core, Devices, OLPC, Wimax/*TODO: mark it deprecated somehow?*/, Infiniband, Firewall, Adsl, Bond, Vlan
-                , Agents, Settings, Bridge, DbusProps, Team, ConCheck, Dcb, Dispatch
-                };
+enum LogDomain {
+    NoChange,
+    None,
+    Hardware,
+    RFKill,
+    Ethernet,
+    WiFi,
+    Bluetooth,
+    MobileBroadBand,
+    DHCP4,
+    DHCP6,
+    PPP,
+    WiFiScan,
+    IPv4,
+    IPv6,
+    AutoIPv4,
+    DNS,
+    VPN,
+    Sharing,
+    Supplicant,
+    UserSet,
+    SysSet,
+    Suspend,
+    Core,
+    Devices,
+    OLPC,
+    Wimax /*TODO: mark it deprecated somehow?*/,
+    Infiniband,
+    Firewall,
+    Adsl,
+    Bond,
+    Vlan,
+    Agents,
+    Settings,
+    Bridge,
+    DbusProps,
+    Team,
+    ConCheck,
+    Dcb,
+    Dispatch,
+};
 Q_DECLARE_FLAGS(LogDomains, LogDomain)
 Q_FLAGS(LogDomain)
 
@@ -81,7 +101,7 @@ enum Connectivity {
     NoConnectivity = 1, /**< The host is not connected to any network. */
     Portal = 2, /**< The host is behind a captive portal and cannot reach the full Internet. */
     Limited = 3, /**< The host is connected to a network, but does not appear to be able to reach the full Internet. */
-    Full = 4 /**< The host is connected to a network, and appears to be able to reach the full Internet. */
+    Full = 4, /**< The host is connected to a network, and appears to be able to reach the full Internet. */
 };
 
 class NETWORKMANAGERQT_EXPORT Notifier : public QObject
@@ -310,18 +330,45 @@ NETWORKMANAGERQT_EXPORT bool isWimaxHardwareEnabled();
  *
  * @param connectionUni unique identifier for the connection to be activated
  * @param interfaceUni unique identifier of the network interface to be activated
- * @param connectionParameter can be used to specify extra parameters not specific to the NetworkInterface or the connection, eg which AP to use when several present with same ESSID in range (because ESSID does not guarantee that the AP is part of the network you want to join!)
+ * @param connectionParameter can be used to specify extra parameters not specific to the NetworkInterface or the connection, eg which AP to use when several
+ * present with same ESSID in range (because ESSID does not guarantee that the AP is part of the network you want to join!)
  */
-NETWORKMANAGERQT_EXPORT QDBusPendingReply<QDBusObjectPath> activateConnection(const QString &connectionUni, const QString &interfaceUni, const QString &connectionParameter);
+NETWORKMANAGERQT_EXPORT QDBusPendingReply<QDBusObjectPath>
+activateConnection(const QString &connectionUni, const QString &interfaceUni, const QString &connectionParameter);
 /**
- * Adds a new connection using the given details (if any) as a template (automatically filling in missing settings with the capabilities of the given device and specific object), then activate the new connection.
- * Cannot be used for VPN connections at this time.
+ * Adds a new connection using the given details (if any) as a template (automatically filling in missing settings with the capabilities of the given device and
+ * specific object), then activate the new connection. Cannot be used for VPN connections at this time.
  *
  * @param connection connection definition to be added and activated
  * @param interfaceUni unique identifier of the network interface to be activated
- * @param connectionParameter can be used to specify extra parameters not specific to the NetworkInterface or the connection, eg which AP to use when several present with same ESSID in range (because ESSID does not guarantee that the AP is part of the network you want to join!)
+ * @param connectionParameter can be used to specify extra parameters not specific to the NetworkInterface or the connection, eg which AP to use when several
+ * present with same ESSID in range (because ESSID does not guarantee that the AP is part of the network you want to join!)
  */
-NETWORKMANAGERQT_EXPORT QDBusPendingReply<QDBusObjectPath, QDBusObjectPath> addAndActivateConnection(const NMVariantMapMap &connection, const QString &interfaceUni, const QString &connectionParameter);
+NETWORKMANAGERQT_EXPORT QDBusPendingReply<QDBusObjectPath, QDBusObjectPath>
+addAndActivateConnection(const NMVariantMapMap &connection, const QString &interfaceUni, const QString &connectionParameter);
+/**
+ * Adds a new connection using the given details (if any) as a template (automatically filling in missing settings with the capabilities of the given device and
+ * specific object), then activate the new connection. Cannot be used for VPN connections at this time.
+ *
+ * @param connection connection definition to be added and activated
+ * @param interfaceUni unique identifier of the network interface to be activated
+ * @param connectionParameter can be used to specify extra parameters not specific to the NetworkInterface or the connection, eg which AP to use when several
+ * present with same ESSID in range (because ESSID does not guarantee that the AP is part of the network you want to join!)
+ * @param options further options for the method call.
+ *
+ * This method extends AddAndActivateConnection to allow passing further
+ * parameters. At this time the following options are supported:
+ *
+ *        * persist: A string value of either "disk" (default), "memory" or "volatile". If "memory" is passed, the connection will not be saved to disk. If
+ * "volatile" is passed, the connection will not be saved to disk and will be destroyed when disconnected.
+ *        * bind-activation: Bind the activation lifetime. Set to "dbus-name" to automatically disconnect when the requesting process disappears from the bus.
+ * The default of "none" means the connection is kept activated normally.
+ *
+ * NOTE: will call AddAndActivateConnection(connection, interfaceUni, connectionParameter) instead when NetworkManager is older than 1.16, which means that the
+ * options property is ignored
+ */
+NETWORKMANAGERQT_EXPORT QDBusPendingReply<QDBusObjectPath, QDBusObjectPath, QVariantMap>
+addAndActivateConnection2(const NMVariantMapMap &connection, const QString &interfaceUni, const QString &connectionParameter, const QVariantMap &options);
 /**
  * Deactivate this network interface, if active
  *
@@ -346,27 +393,27 @@ NETWORKMANAGERQT_EXPORT QStringList activeConnectionsPaths();
 NETWORKMANAGERQT_EXPORT QDBusPendingReply<QString, QString> getLogging();
 
 /**
-  * @return the network connectivity state
-  * @since 0.9.9.0
+ * @return the network connectivity state
+ * @since 0.9.9.0
  */
 NETWORKMANAGERQT_EXPORT Connectivity connectivity();
 
 /**
-  * Re-check the network connectivity state.
-  * @see connectivity()
-  * @since 0.9.9.0
+ * Re-check the network connectivity state.
+ * @see connectivity()
+ * @since 0.9.9.0
  */
 NETWORKMANAGERQT_EXPORT QDBusPendingReply<uint> checkConnectivity();
 
 /**
-  * @return the "primary" active connection being used
-  * to access the network. In particular, if there is no VPN
-  * active, or the VPN does not have the default route, then this
-  * indicates the connection that has the default route. If there
-  * is a VPN active with the default route, then this indicates
-  * the connection that contains the route to the VPN endpoint.
-  * @since 0.9.9.0
-  */
+ * @return the "primary" active connection being used
+ * to access the network. In particular, if there is no VPN
+ * active, or the VPN does not have the default route, then this
+ * indicates the connection that has the default route. If there
+ * is a VPN active with the default route, then this indicates
+ * the connection that contains the route to the VPN endpoint.
+ * @since 0.9.9.0
+ */
 NETWORKMANAGERQT_EXPORT ActiveConnection::Ptr primaryConnection();
 
 /**
@@ -386,11 +433,11 @@ NETWORKMANAGERQT_EXPORT ActiveConnection::Ptr activatingConnection();
 NETWORKMANAGERQT_EXPORT NetworkManager::ConnectionSettings::ConnectionType primaryConnectionType();
 
 /**
-  * Indicates whether NM is still starting up; this becomes @p false
-  * when NM has finished attempting to activate every connection
-  * that it might be able to activate at startup.
-  * @since 0.9.9.0
-  */
+ * Indicates whether NM is still starting up; this becomes @p false
+ * when NM has finished attempting to activate every connection
+ * that it might be able to activate at startup.
+ * @since 0.9.9.0
+ */
 NETWORKMANAGERQT_EXPORT bool isStartingUp();
 
 /**
